@@ -173,7 +173,12 @@ def main() -> None:
         action="store_true",
         help="The spec is self-contained, do not bundle any extra directories in the tar file.",
     )
-    echidnaParser.add_argument("--just-tar", dest="justTar", action="store_true")
+    echidnaParser.add_argument(
+        "--just-tar",
+        dest="justTar",
+        action="store_true",
+        help="Don't actually submit to the echidna service, instead just echo the prepared TAR file to stdout.",
+    )
 
     watchParser = subparsers.add_parser(
         "watch",
@@ -497,7 +502,8 @@ def handleEchidna(options: argparse.Namespace, extras: list[str]) -> None:
     doc.preprocess()
     addDirs = [] if options.selfContained else options.additionalDirectories
     if options.justTar:
-        publish.prepareTar(doc, visibleTar=True, additionalDirectories=addDirs)
+        tarBytes = publish.prepareTar(doc, additionalDirectories=addDirs)
+        sys.stdout.buffer.write(tarBytes)
     else:
         publish.publishEchidna(
             doc,
