@@ -2,7 +2,6 @@
 
 from __future__ import annotations
 
-import copy
 import dataclasses
 import json
 import os
@@ -15,6 +14,7 @@ from functools import partial
 from isodate import Duration, parse_duration
 
 from . import config, constants, datablocks, markdown, h, messages as m, repository, t
+from .translate import _
 
 if t.TYPE_CHECKING:
     from .line import Line
@@ -61,7 +61,7 @@ class MetadataManager:
         self.boilerplate: config.BoolSet = config.BoolSet(default=True)
         self.canIUseURLs: list[str] = []
         self.canonicalURL: str | None = None
-        self.complainAbout: config.BoolSet = config.BoolSet()
+        self.complainAbout: config.BoolSet = config.BoolSet(["mixed-indents"])
         self.customTextMacros: list[tuple[str, str]] = []
         self.customWarningText: list[str] = []
         self.customWarningTitle: str | None = None
@@ -71,7 +71,7 @@ class MetadataManager:
         self.defaultBiblioDisplay: str = "index"
         self.defaultRefStatus: str | None = None
         self.editors: list[dict[str, str | None]] = []
-        self.editorTerm: dict[str, str] = {"singular": "Editor", "plural": "Editors"}
+        self.editorTerm: dict[str, str] = {"singular": _("Editor"), "plural": _("Editors")}
         self.expires: date | None = None
         self.externalInfotrees: config.BoolSet = config.BoolSet(default=False)
         self.favicon: str | None = None
@@ -120,12 +120,12 @@ class MetadataManager:
         self.title: str | None = None
         self.toggleDiffs: bool = False
         self.TR: str | None = None
-        self.trackingVectorAltText: str = "(This is a tracking vector.)"
+        self.trackingVectorAltText: str = _("(This is a tracking vector.)")
         self.trackingVectorClass: str = "tracking-vector"
         self.trackingVectorImage: str | None = None
         self.trackingVectorImageHeight: str = "64"
         self.trackingVectorImageWidth: str = "46"
-        self.trackingVectorTitle: str = "There is a tracking vector here."
+        self.trackingVectorTitle: str = _("There is a tracking vector here.")
         self.translateIDs: dict[str, str] = {}
         self.translations: list[dict[str, str]] = []
         self.useDfnPanels: bool = True
@@ -343,7 +343,7 @@ class MetadataManager:
         if self.logo:
             macros["logo"] = self.logo
         if self.repository:
-            macros["repository"] = self.repository.name or "Unnamed Repo"
+            macros["repository"] = self.repository.name or _("Unnamed Repo")
             macros["repositoryurl"] = self.repository.url
         if self.mailingList:
             macros["mailinglist"] = self.mailingList
@@ -659,7 +659,9 @@ def parseRefStatus(key: str, val: str, lineNum: str | int | None) -> str:
 
 
 def parseComplainAbout(key: str, val: str, lineNum: str | int | None) -> config.BoolSet:
-    validLabels = frozenset(["missing-example-ids", "broken-links", "accidental-2119", "missing-exposed"])
+    validLabels = frozenset(
+        ["missing-example-ids", "broken-links", "accidental-2119", "missing-exposed", "mixed-indents"]
+    )
     ret = parseBoolishList(key, val.lower(), default=False, validLabels=validLabels, lineNum=lineNum)
     return ret
 
@@ -1168,7 +1170,8 @@ def joinDict(a: t.Mapping[str, JoinA], b: t.Mapping[str, JoinB]) -> dict[str, Jo
 
 
 def joinBoolSet(a: config.BoolSet, b: config.BoolSet) -> config.BoolSet:
-    x = copy.deepcopy(a)
+    x = config.BoolSet()
+    x.update(a)
     x.update(b)
     return x
 
