@@ -459,6 +459,13 @@ class ReferenceManager:
                     linkType = dfnType
                     break
 
+        if spec == "css2":
+            # TEMP - moving data sources changed css2 to css22,
+            # so manually fix it up for a little while
+            spec = "css22"
+            if error:
+                m.linkerror(f"The spec 'css2' was renamed to 'css22'; please update your links.")
+
         # Then anchor-block refs get preference
         blockRefs, _ = self.anchorBlockRefs.queryRefs(
             linkType=linkType,
