@@ -298,12 +298,13 @@ def addVarClickHighlighting(doc: t.SpecT) -> None:
     doc.extraScripts[
         "script-var-click-highlighting"
     ] = r"""
-    document.addEventListener("click", e=>{
-        if(e.target.nodeName == "VAR") {
-            highlightSameAlgoVars(e.target);
-        }
-    });
+    "use strict";
     {
+        document.addEventListener("click", e=>{
+            if(e.target.nodeName == "VAR") {
+                highlightSameAlgoVars(e.target);
+            }
+        });
         const indexCounts = new Map();
         const indexNames = new Map();
         function highlightSameAlgoVars(v) {
@@ -832,6 +833,9 @@ def processBiblioLinks(doc: t.SpecT) -> None:
             ):  # False if it's already been replaced by an author supplied text using the [[FOOBAR inline|custom text]] syntax.
                 h.clearContents(el)
                 h.appendChild(el, h.E.cite(ref.title))
+        else:
+            if ref.title:
+                el.set("title", ref.title)
         if biblioDisplay in ("inline", "direct"):
             if ref.url:
                 el.set("href", ref.url)
